boost\_histogram.cpp.axis
=========================

.. automodule:: boost_histogram.cpp.axis
   :members:
   :undoc-members:
   :show-inheritance:


boost\_histogram.cpp.axis.transform
===================================

.. automodule:: boost_histogram.cpp.axis.transform
   :members:
   :undoc-members:
   :show-inheritance:

